@@ -5,9 +5,11 @@ import numpy
 
 from plotly.figure_factory._2d_density import create_2d_density
 from plotly.figure_factory._annotated_heatmap import create_annotated_heatmap
+from plotly.figure_factory._bullet import create_bullet
 from plotly.figure_factory._candlestick import create_candlestick
 from plotly.figure_factory._dendrogram import create_dendrogram
 from plotly.figure_factory._distplot import create_distplot
+from plotly.figure_factory._facet_grid import create_facet_grid
 from plotly.figure_factory._gantt import create_gantt
 from plotly.figure_factory._ohlc import create_ohlc
 from plotly.figure_factory._quiver import create_quiver
